@@ -89,9 +89,15 @@ FAILEDOPERATION_REQUESTENTITYTOOLARGE = 'FailedOperation.RequestEntityTooLarge'
 # 后端服务超时，请重试。
 FAILEDOPERATION_REQUESTTIMEOUT = 'FailedOperation.RequestTimeout'
 
+# RPC请求失败，一般为算法微服务故障。
+FAILEDOPERATION_RPCFAIL = 'FailedOperation.RpcFail'
+
 # 系统内部错误。
 FAILEDOPERATION_SERVERERROR = 'FailedOperation.ServerError'
 
+# 未知错误。
+FAILEDOPERATION_UNKNOWN = 'FailedOperation.Unknown'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
