@@ -176,6 +176,9 @@ FAILEDOPERATION_UNTAGRESOURCESFAILED = 'FailedOperation.UnTagResourcesFailed'
 # 用户未认证。
 FAILEDOPERATION_USERNOTAUTHENTICATED = 'FailedOperation.UserNotAuthenticated'
 
+# 未开通协议。
+FAILEDOPERATION_USERNOTCONFIRMPROTOCOL = 'FailedOperation.UserNotConfirmProtocol'
+
 # 该用户不在运营商网络可加速范围内。
 FAILEDOPERATION_USEROUTOFCOVERAGE = 'FailedOperation.UserOutOfCoverage'
 
@@ -212,6 +215,9 @@ INVALIDPARAMETERVALUE_DUPLICATEDLISTENERPORT = 'InvalidParameterValue.Duplicated
 # 无法同时开启所设置的特性。
 INVALIDPARAMETERVALUE_FEATURECONFLICT = 'InvalidParameterValue.FeatureConflict'
 
+# 该默认入口被封禁，无法添加。
+INVALIDPARAMETERVALUE_GLOBALDOMAINHITBANBLACKLIST = 'InvalidParameterValue.GlobalDomainHitBanBlacklist'
+
 # 资源已被录入封禁黑名单。
 INVALIDPARAMETERVALUE_HITBANBLACKLIST = 'InvalidParameterValue.HitBanBlacklist'
 
@@ -263,6 +269,9 @@ INVALIDPARAMETERVALUE_UNKNOWNDESTREGION = 'InvalidParameterValue.UnknownDestRegi
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 域名数量超限制。
+LIMITEXCEEDED_DOMAIN = 'LimitExceeded.Domain'
+
 # 标签配额不足。
 LIMITEXCEEDED_TAGQUOTA = 'LimitExceeded.TagQuota'
 
