@@ -36,7 +36,8 @@ class MnaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateQos", params)
+            headers = request.headers
+            body = self.call("CreateQos", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateQosResponse()
@@ -64,7 +65,8 @@ class MnaClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteQos", params)
+            headers = request.headers
+            body = self.call("DeleteQos", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteQosResponse()
@@ -75,6 +77,35 @@ class MnaClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeQos(self, request):
+        """获取Qos加速状态
+
+        :param request: Request instance for DescribeQos.
+        :type request: :class:`tencentcloud.mna.v20210119.models.DescribeQosRequest`
+        :rtype: :class:`tencentcloud.mna.v20210119.models.DescribeQosResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeQos", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeQosResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
